@@ -65,6 +65,13 @@ def Output():
 def FMDIL():
     a = [1, 2, 3, 1, 2, 3, 2, 2, 4, 5, 1]
     print(max(set(a), key=a.count))
+def Kwargs():
+    dictionary = {"a": 1, "b": 2}
+    def some_function(a, b):
+        print(a + b)
+        return
+    some_function(**dictionary)
+    some_function(a=1, b=2)
 while True:
     print("1. Welcome")
     print("2. sum0391")
@@ -82,6 +89,7 @@ while True:
     print("14. Dictionary and set generators")
     print("15. Output with print")
     print("16. Finding the Most Duplicate Items in a List")
+    print("17. Kwargs")
     print("0. Quit")
     cmd = input("Select an item: ")
     
@@ -117,6 +125,8 @@ while True:
         Output()
     elif cmd == "16":
         FMDIL()
+    elif cmd == "17":
+        Kwargs()
     elif cmd == "0":
         exit()
     else:
