@@ -1,5 +1,4 @@
-import main as stern
-
+from main import stern
 stern.sumAB(a,b)
 stern.SealN()
 stern.flip()
@@ -14,4 +13,5 @@ stern.EVT()
 stern.StringConcatenation()
 stern.DictionaryGenerators()
 stern.Output()
-stern.FMDIL()
\ No newline at end of file
+stern.FMDIL()
+stern.Kwargs()
\ No newline at end of file
